@@ -11,7 +11,6 @@
 @interface DataFile : MyItem {
   unsigned size;
 	NSString *filename;
-	unsigned fileID;
 //	NSDate *timestamp;
 	NSString *fullPath;
 }
@@ -19,19 +18,11 @@
 - (unsigned int)size;
 - (void)setFilename:(NSString *)newFilename;
 - (NSString *)filename;
-- (void)setFileID:(unsigned)newFileID;
-- (unsigned int)fileID;
 //- (void)setTimestamp:(NSDate *)newTimestamp;
 //- (void)setTimestampSince1970:(unsigned int)newTimestamp;
 //- (NSDate *)timestamp;
 - (void)setFullPath:(NSString *)newFullPath;
 - (NSString *)fullPath;
-+ (SEL)compareBySizeSelector;
-//+ (SEL)compareByTimestampSelector;
-+ (SEL)compareByFilenameSelector;
-- (NSComparisonResult)compareBySize:(DataFile *)other;
-//- (NSComparisonResult)compareByTimestamp:(DataFile *)other;
-- (NSComparisonResult)compareByFilename:(DataFile *)other;
 - (NSString *)sizeString;
 //- (NSString *)timestampString;
 + (DataFile *)dataFileFromPath:(NSString *)path;
