@@ -40,10 +40,9 @@
 	[self loadFiles];
 }
 
-- (void)awakeFromNib
+- (NSString *)browserPathFromPreferences
 {
-	[super awakeFromNib];
-	[browser setBaseLocation:[preferences dataTabDir]];
+	return [preferences dataTabDir];
 }
 
 /* add downloadFileList to the NJB queue
