@@ -126,7 +126,13 @@
  */
 - (void)showTrack:(Track *)track
 {
+	// don't do anything if we are told to show what we are already showing
+	// this avoids removing someone's edits also
+	if (displayedTrack == track)
+		return;
+	
 	// empty all fields in case we don't fill them here
+	// this will release displayedTrack but we know it's not the same as track so OK
 	[self clearAll];
 	
 	[self enableAll];
@@ -140,12 +146,15 @@
 	if ([track genre])
 		[genreCombo setStringValue:[track genre]];
 	[yearField setStringValue:[NSString stringWithFormat:@"%d", [track year]]];
-	[codecField setStringValue:[track codecString]];
-	[lengthField setStringValue:[track lengthString]];
+	if ([track codecString])
+		[codecField setStringValue:[track codecString]];
+	if ([track lengthString])
+		[lengthField setStringValue:[track lengthString]];
 	
 	if ([track title])
 		[titleField setStringValue:[track title]];
-	[filesizeField setStringValue:[track filesizeString]];
+	if ([track filesizeString])
+		[filesizeField setStringValue:[track filesizeString]];
 	
 	[track retain];
 	[displayedTrack release];
@@ -160,6 +169,11 @@
 	// disable and clear all, including write button
 	[self disableAll];
 	
+	// might be the case if the item selected
+	// has been deleted.
+	if (dataFile == nil)
+		return;
+	
 	[titleField setEnabled:YES];
 	[titleField setEditable:NO];
 	[filesizeField setEnabled:YES];
@@ -251,6 +265,8 @@
 	[filesizeField setStringValue:@""];
 	[codecField setStringValue:@""];
 	[yearField setStringValue:@""];
+	[displayedTrack release];
+	displayedTrack = nil;
 }
 
 @end
