@@ -51,14 +51,18 @@
 
 /**********************/
 
-- (void)awakeFromNib
+- (NSString *)browserPathFromPreferences
+{
+	return [preferences musicTabDir];
+}
+
+- (NSArray *)allowedExtensions
 {
-	[super awakeFromNib];
 	NSArray *extensions = [NSArray arrayWithObjects:@"mp3", @"wma", @"wav", nil];
-	[browser setAllowedExtensions:extensions];
-	[browser setBaseLocation:[preferences musicTabDir]];
 	
 	[njbTable setAllowedExtensions:extensions];
+	
+	return extensions;
 }
 
 - (void)onConnectAndActive
@@ -456,7 +460,7 @@
 }
 
 - (void)activate
-{
+{	
 	[super activate];
 	if ([theNJB isConnected] && !trackListUpToDate)
 	{
