@@ -37,7 +37,7 @@
 - (void)awakeFromNib
 {
 	[super awakeFromNib];
-	browser = [[FileSystemBrowser alloc] initWithBrowser:fileBrowser atLocation:@"/"];
+	browser = [[FileSystemBrowser alloc] initWithBrowser:fileBrowser atLocation:[self browserPathFromPreferences] withAllowedExtensions:[self allowedExtensions]];
 	[browser setTarget:self];
 	[browser setFileAction:@selector(fileSystemBrowserFileClick:)];
 	[browser setDirectoryAction:@selector(fileSystemBrowserDirectoryClick:)];
@@ -364,6 +364,7 @@
 - (void)addToArray:(MyItem *)item
 {
 	[arrayController addObject:item];
+	[arrayController search:njbSearchField];
 	[self sortArrays];
 	[self showItemCounts];
 }
@@ -395,4 +396,16 @@
 	[drawerController disableAll];
 }
 
+/*
+ * return the browser path stored from preferences
+ * to be implemented by super class
+ */
+- (NSString *)browserPathFromPreferences{ return @"/"; }
+
+/*
+ * return the extensions allowed to be selected
+ * default: all allowed (return nil)
+ */
+- (NSArray *)allowedExtensions{ return nil; }
+
 @end
