@@ -35,6 +35,10 @@ StatusDisplayer *statusDisplayerGlobal;
 - (NSString *)njbErrorString;
 - (NSString *)rateString:(double) rate;
 - (NSString *)uniqueFilename:(NSString *)path;
+// we make this private so that the user never changes the setting directly
+// so we only change it before a transfer, so it is not changed during a transfer
+// which could mess things up
+- (void)enableTurbo;
 @end
 
 @implementation NJB
@@ -47,6 +51,7 @@ StatusDisplayer *statusDisplayerGlobal;
 	{
 		njb = NULL;
 		[self setDebug:0];
+		[self setTurbo:YES];
 	}
 	return self;
 }
@@ -108,6 +113,11 @@ StatusDisplayer *statusDisplayerGlobal;
 	return deviceVersionString;
 }
 
+- (void)setTurbo:(BOOL)newTurbo
+{
+	turbo = newTurbo;
+}
+
 /**********************/
 
 - (void)awakeFromNib
@@ -359,6 +369,10 @@ StatusDisplayer *statusDisplayerGlobal;
 	NSDate *date = [NSDate date];
 	if (![self isConnected])
 		return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:@"Not connected"] autorelease];
+	
+	// set turbo on/off
+	[self enableTurbo];
+	
 	[self setStatus:STATUS_UPLOADING_TRACK];
 	unsigned int trackid;
 	njb_songid_t *songid = [self songidStructFromTrack:track];
@@ -427,6 +441,9 @@ StatusDisplayer *statusDisplayerGlobal;
 
 - (NJBTransactionResult *)downloadTrack:(Track *)track
 {
+	// set turbo on/off
+	[self enableTurbo];
+	
 	// check to see we're not going to overwrite anything
 	NSString *fullPath = [track fullPath];
 	fullPath = [self uniqueFilename:fullPath];
@@ -555,6 +572,9 @@ StatusDisplayer *statusDisplayerGlobal;
 
 - (NJBTransactionResult *)downloadFile:(DataFile *)dataFile
 {
+	// set turbo on/off
+	[self enableTurbo];
+	
 	// check to see we're not going to overwrite anything
 	NSString *fullPath = [dataFile fullPath];
 	fullPath = [self uniqueFilename:fullPath];
@@ -579,6 +599,10 @@ StatusDisplayer *statusDisplayerGlobal;
 {
 	if (![self isConnected])
 		return [[[NJBTransactionResult alloc] initWithSuccess:NO] autorelease];
+	
+	// set turbo on/off
+	[self enableTurbo];
+	
 	NSDate *date = [NSDate date];
 	[self setStatus:STATUS_UPLOADING_FILE];
 	unsigned int fileid;
@@ -947,4 +971,14 @@ int progress(u_int64_t sent, u_int64_t total, const char* buf, unsigned len, voi
 	return @"Running off battery";
 }
 
+- (void)enableTurbo
+{
+	//NSLog(@"enableTurbo : %d", turbo);
+
+	if (turbo)
+		NJB_Set_Turbo_Mode(njb, NJB_TURBO_ON);
+	else
+		NJB_Set_Turbo_Mode(njb, NJB_TURBO_OFF);
+}
+
 @end
