@@ -66,6 +66,7 @@
 {
 	[self setStateForButton:connectOnStartup fromBool:[preferences connectOnStartup]];
 	[self setStateForButton:writeTagAfterCopy fromBool:[preferences writeTagAfterCopy]];
+	[self setStateForButton:enableTurbo fromBool:[preferences turbo]];
 	[self setStateForButton:startupTabLastUsed fromBool:[preferences startupTabLastUsed]];
 	if (![preferences startupTabLastUsed])
 	{
@@ -153,6 +154,7 @@
 {
 	[preferences setConnectOnStartup:[self boolForButton:connectOnStartup]];
 	[preferences setWriteTagAfterCopy:[self boolForButton:writeTagAfterCopy]];
+	[preferences setTurbo:[self boolForButton:enableTurbo]];
 	if ([startupTabLastUsed state] == NSOnState)
 		[preferences setStartupTabLastUsed:YES];
 	else
@@ -343,6 +345,11 @@
 	isDirty = YES;
 }
 
+- (IBAction)enableTurbo:(id)sender
+{
+	isDirty = YES;
+}
+
 - (BOOL)isDirty
 {
 	if (isDirty)
