@@ -15,6 +15,7 @@ typedef enum _itemStatusTypes {ITEM_STATUS_QUEUED = 0, ITEM_STATUS_RUNNING = 1,
 	NJBQueueItem *mainItem;
 	NSArray *subItems;
 	NSString *description;
+	NSString *resultString;
 	itemStatusTypes status;
 }
 - (id)initWithMainItem:(NJBQueueItem *)newMainItem withSubItems:(NSArray *)newSubItems;
@@ -26,5 +27,7 @@ typedef enum _itemStatusTypes {ITEM_STATUS_QUEUED = 0, ITEM_STATUS_RUNNING = 1,
 - (void)setStatus:(itemStatusTypes)status;
 - (NSString *)description;
 - (void)setDescription:(NSString *)descriptions;
+- (void)setResultString:(NSString *)newResultString;
+- (NSString *)resultString;
 
 @end
