@@ -10,7 +10,6 @@
  */
 #import "Track.h"
 #import "FilesizeFormatter.h"
-#import "MyMutableArray.h"
 
 @implementation Track
 
@@ -32,7 +31,6 @@
 		[self setFilesize:0];
 		[self setLength:0];
 		[self setCodec:CODEC_UNDEFINED];
-		[self setTrackID:0];
 	}
 	return self;
 }
@@ -41,18 +39,7 @@
 {
 	if (self = [super init])
 	{
-		[self setTitle:[track title]];
-		[self setArtist:[track artist]];
-		[self setAlbum:[track album]];
-		[self setGenre:[track genre]];
-		[self setFilename:[track filename]];
-		[self setFullPath:[track fullPath]];
-		[self setTrackNumber:[track trackNumber]];
-		[self setYear:[track year]];
-		[self setFilesize:[track filesize]];
-		[self setLength:[track length]];
-		[self setCodec:[track codec]];
-		[self setTrackID:[track trackID]];
+		[self setValuesToTrack:track];
 	}
 	return self;
 }
@@ -76,17 +63,12 @@
 - (void)setTitle:(NSString *)newTitle
 {
 	if (newTitle == nil)
-	{
-		title = @"";
-		[title release];
-	}
-	else
-	{
-		// get immutable copy
-		newTitle = [newTitle copy];
-		[title release];
-		title = newTitle;
-	}
+		newTitle = @"";
+	// get immutable copy
+	newTitle = [NSString stringWithString:newTitle];
+	[newTitle retain];
+	[title release];
+	title = newTitle;
 }
 
 - (NSString *)album
@@ -97,17 +79,12 @@
 - (void)setAlbum:(NSString *)newAlbum
 {
 	if (newAlbum == nil)
-	{
-		[album release];
-		album = @"";
-	}
-	else
-	{
-		// get immutable copy
-		newAlbum = [newAlbum copy];
-		[album release];
-		album = newAlbum;
-	}
+		newAlbum = @"";
+	// get immutable copy
+	newAlbum = [NSString stringWithString:newAlbum];
+	[newAlbum retain];
+	[album release];
+	album = newAlbum;
 }
 
 - (NSString *)artist
@@ -118,17 +95,12 @@
 - (void)setArtist:(NSString *)newArtist
 {
 	if (newArtist == nil)
-	{
-		[artist release];
-		artist = @"";
-	}
-	else
-	{
-		// get immutable copy
-		newArtist = [newArtist copy];
-		[artist release];
-		artist = newArtist;
-	}
+		newArtist = @"";
+	// get immutable copy
+	newArtist = [NSString stringWithString:newArtist];
+	[newArtist retain];
+	[artist release];
+	artist = newArtist;
 }
 
 - (NSString *)genre
@@ -139,17 +111,12 @@
 - (void)setGenre:(NSString *)newGenre
 {
 	if (newGenre == nil)
-	{
-		[genre release];
-		genre = @"";
-	}
-	else
-	{
-		// get immutable copy
-		newGenre = [newGenre copy];
-		[genre release];
-		genre = newGenre;
-	}
+		newGenre = @"";
+	// get immutable copy
+	newGenre = [NSString stringWithString:newGenre];
+	[newGenre retain];
+	[genre release];
+	genre = newGenre;
 }
 
 - (NSString *)filename
@@ -160,17 +127,12 @@
 - (void)setFilename:(NSString *)newFilename
 {
 	if (newFilename == nil)
-	{
-		[filename release];
-		filename = @"";
-	}
-	else
-	{
-		// get immutable copy
-		newFilename = [newFilename copy];
-		[filename release];
-		filename = newFilename;
-	}
+		newFilename = @"";
+	// get immutable copy
+	newFilename = [NSString stringWithString:newFilename];
+	[newFilename retain];
+	[filename release];
+	filename = newFilename;
 }
 
 - (NSString *)fullPath
@@ -181,17 +143,12 @@
 - (void)setFullPath:(NSString *)newFullPath
 {
 	if (newFullPath == nil)
-	{
-		[fullPath release];
-		fullPath = @"";
-	}
-	else
-	{
-		// get immutable copy
-		newFullPath = [newFullPath copy];
-		[fullPath release];
-		fullPath = newFullPath;
-	}
+		newFullPath = @"";
+	// get immutable copy
+	newFullPath = [NSString stringWithString:newFullPath];
+	[newFullPath retain];
+	[fullPath release];
+	fullPath = newFullPath;
 }
 
 - (unsigned)length
@@ -256,6 +213,9 @@
 		case CODEC_WAV:
 			return @"WAV";
 			break;
+		case CODEC_AA:
+			return @"AA";
+			break;
 		default:
 			NSLog(@"Invalid codec in codecString, title %@", title);
 			return nil;
@@ -292,23 +252,29 @@
 	filesize = newFilesize;
 }
 
-- (unsigned)trackID
-{
-	return trackID;
-}
-
-- (void)setTrackID:(unsigned)newTrackID
-{
-	trackID = newTrackID;
-}
-
 /**********************/
 
+- (void)setValuesToTrack:(Track *)track
+{
+	[self setTitle:[track title]];
+	[self setArtist:[track artist]];
+	[self setAlbum:[track album]];
+	[self setGenre:[track genre]];
+	[self setFilename:[track filename]];
+	[self setFullPath:[track fullPath]];
+	[self setTrackNumber:[track trackNumber]];
+	[self setYear:[track year]];
+	[self setFilesize:[track filesize]];
+	[self setLength:[track length]];
+	[self setCodec:[track codec]];
+	[self setItemID:[track itemID]];
+}
+
 - (NSString *)description
 {
 	return [NSString stringWithFormat:@"Title: %@, Artist: %@, Album: %@, Genre: %@, Length: %@, Track No: %d, Codec: %@, Filesize: %@, Track ID: %d, Year: %d, Filename: %@, Fullpath: %@",
 		title, artist, album, genre, [self lengthString], trackNumber,
-		[self codecString], [self filesizeString], trackID, year, filename, fullPath];
+		[self codecString], [self filesizeString], itemID, year, filename, fullPath];
 }
 
 /* searches title, album, artist and genre for the string
@@ -334,93 +300,21 @@
 	return YES;	
 }
 
-// comparison methods
-
-- (NSComparisonResult)compareByFilesize:(Track *)other
+- (NSComparisonResult)compareByLength:(Track *)other
 {
-	return [self compareUnsignedInts:filesize withOther:[other filesize] withItem:other withSortSelector:@selector(compareByFilesize:)];
+	return [self compareUnsignedInts:length withOther:[other length]];
 }
 
-+ (SEL)compareByFilesizeSelector
+/* this compares the two unsigned ints mine and theirs
+ */
+- (NSComparisonResult)compareUnsignedInts:(unsigned)mine withOther:(unsigned)theirs
 {
-	return @selector(compareByFilesize:);
-}
-
-- (NSComparisonResult)compareByLength:(Track *)other {
-	return [self compareUnsignedInts:length withOther:[other length] withItem:other withSortSelector:@selector(compareByLength:)];
-}
-
-+ (SEL)compareByLengthSelector
-{
-	return @selector(compareByLength:);
-}
-
-- (NSComparisonResult)compareByTitle:(Track *)other
-{
-	return [self compareStrings:title withOther:[other title] withItem:other withSortSelector:@selector(compareByTitle:)];
-}
-
-+ (SEL)compareByTitleSelector
-{
-	return @selector(compareByTitle:);
-}
-
-- (NSComparisonResult)compareByArtist:(Track *)other
-{
-	return [self compareStrings:artist withOther:[other artist] withItem:other withSortSelector:@selector(compareByArtist:)];
-}
-
-+ (SEL)compareByArtistSelector
-{
-	return @selector(compareByArtist:);
-}
-
-- (NSComparisonResult)compareByAlbum:(Track *)other
-{
-	return [self compareStrings:album withOther:[other album] withItem:other withSortSelector:@selector(compareByAlbum:)];
-}
-
-+ (SEL)compareByAlbumSelector
-{
-	return @selector(compareByAlbum:);
-}
-
-- (NSComparisonResult)compareByGenre:(Track *)other
-{
-	return [self compareStrings:genre withOther:[other genre] withItem:other withSortSelector:@selector(compareByGenre:)];
-}
-
-+ (SEL)compareByGenreSelector
-{
-	return @selector(compareByGenre:);
-}
-
-- (NSComparisonResult)compareByCodec:(Track *)other {
-	return [self compareUnsignedInts:codec withOther:[other codec] withItem:other withSortSelector:@selector(compareByCodec:)];
-}
-
-+ (SEL)compareByCodecSelector
-{
-	return @selector(compareByCodec:);
-}
-
-- (NSComparisonResult)compareByTrackNumber:(Track *)other {
-	return [self compareUnsignedInts:trackNumber withOther:[other trackNumber] withItem:other withSortSelector:@selector(compareByTrackNumber:)];
-}
-
-+ (SEL)compareByTrackNumberSelector
-{
-	return @selector(compareByTrackNumber:);
-}
-
-- (NSComparisonResult)compareByYear:(Track *)other
-{
-	return [self compareUnsignedInts:year withOther:[other year] withItem:other withSortSelector:@selector(compareByYear:)];
-}
-
-+ (SEL)compareByYearSelector
-{
-	return @selector(compareByYear:);
+	if (mine == theirs)
+			return NSOrderedSame;
+	else if (mine < theirs)
+		return NSOrderedAscending;
+	else
+		return NSOrderedDescending;
 }
 
 @end
